==> tai_test_utils-0.4.2.tar.gz: tai_test_utils-0.4.2/setup.py <==
# Copyright (c) AffectLog SAS
# Licensed under the MIT License.

import setuptools

with open('tai_test_utils/version.py') as f:
    code = compile(f.read(), f.name, 'exec')
    exec(code)

# Fetch ReadMe
with open("README.md", "r") as fh:
    long_description = fh.read()

# Use requirements.txt to set the install_requires
with open('requirements.txt') as f:
    install_requires = [line.strip() for line in f]

# Use requirements-object-detection.txt to set the install_requires
with open('requirements-object-detection.txt') as f:
    extras_require = {
        'object_detection': [line.strip() for line in f]
    }

setuptools.setup(
    name=name,
    version=version,
    author="AL360°",
    author_email="developer@affectlog.com",
    description="Common basic test utilities used across various RAI tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/affectlog/trustworthy-ai-toolbox",
    packages=setuptools.find_packages(),
    python_requires='>=3.7',
    install_requires=install_requires,
    extras_require=extras_require,
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha"
    ]
)

==> tai_test_utils-0.4.3.tar.gz: tai_test_utils-0.4.3/setup.py <==
# Copyright (c) AffectLog SAS
# Licensed under the MIT License.

import setuptools

with open('tai_test_utils/version.py') as f:
    code = compile(f.read(), f.name, 'exec')
    exec(code)

# Fetch ReadMe
with open("README.md", "r") as fh:
    long_description = fh.read()

# Use requirements.txt to set the install_requires
with open('requirements.txt') as f:
    install_requires = [line.strip() for line in f]

# Use requirements-object-detection.txt to set the install_requires
with open('requirements-object-detection.txt') as f:
    extras_require = {
        'object_detection': [line.strip() for line in f]
    }

setuptools.setup(
    name=name,
    version=version,
    author="AL360°",
    author_email="developer@affectlog.com",
    description="Common basic test utilities used across various TAI tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/affectlog/trustworthy-ai-toolbox",
    packages=setuptools.find_packages(),
    python_requires='>=3.7',
    install_requires=install_requires,
    extras_require=extras_require,
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha"
    ]
)
